## $Id: permissions.py 17866 2024-08-01 11:02:51Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
More permissions and roles for the students section.
"""
import grok


class ClearStudentFinancially(grok.Permission):
    """The ClearStudentFinancially permission is needed to clear students
    financially or to reject financial clearance. This permission is
    meant for financial clearance officers.
    """
    grok.name('waeup.clearStudentFinancially')


class FinancialClearanceOfficer(grok.Role):
    """Financial Clearance Officers are also allowed to clear
    students financially. Usually this role is assigned together
    with the BursaryOfficer role and the StudentsOfficer role.
    """
    grok.name('waeup.FinancialClearanceOfficer')
    grok.title(u'Financial Clearance Officer')
    grok.permissions('waeup.clearStudentFinancially')

class ClearStudentFinally(grok.Permission):
    """The ClearStudentFinally permission is needed to clear students
    finally or to reject final clearance. This permission is
    meant for final clearance officers.
    """
    grok.name('waeup.clearStudentFinally')


class FinalClearanceOfficer(grok.Role):
    """Final Clearance Officers are also allowed to clear
    students finally. Usually this role is assigned together
    with the BursaryOfficer role and the StudentsOfficer role.
    """
    grok.name('waeup.FinalClearanceOfficer')
    grok.title(u'Final Clearance Officer')
    grok.permissions('waeup.clearStudentFinally')